package net.minecraft.src.forestry.api;

import java.util.ArrayList;
import java.util.HashMap;

import net.minecraft.src.EntityPlayer;
import net.minecraft.src.IInventory;
import net.minecraft.src.ItemStack;

public abstract class Harvester {
	private HashMap<Integer, Yield> validYieldByRipeId = new HashMap<Integer, Yield>(); // Ids of valid items/blocks to use for planting, keyed by seedid;
	private HashMap<Integer, Yield> validYieldByPluckedId = new HashMap<Integer, Yield>(); // Ids of valid items/blocks to use for planting, keyed by seedid;
	private ArrayList<Integer> validWindfallById = new ArrayList<Integer>();
	
	public abstract void openGui(EntityPlayer player, IInventory tile);
	
	protected void putYield(Yield yield)
	{
		validYieldByRipeId.put(yield.ripeId, yield);
		validYieldByPluckedId.put(yield.plucked.itemID, yield);
	}
	
	protected void putWindfall(int id)
	{
		validWindfallById.add(id);
	}
	
	public boolean hasYieldByRipeId(int id)
	{
		return validYieldByRipeId.containsKey(id);
	}
	
	public boolean hasYieldByPluckedId(int id)
	{
		return validYieldByPluckedId.containsKey(id);
	}
	
	public boolean hasWindfallById(int id)
	{
		return validWindfallById.contains(id);
	}
	
	public Yield getYieldByRipeId(int id)
	{
		return validYieldByRipeId.get(id);
	}
	
	public ItemStack getPluckedByRipeId(int id)
	{
		Yield yield = validYieldByRipeId.get(id);
		return yield.plucked;
	}

}
